==> youtui-center-api-0.0.1.11-yuanwei3-20180801.150133-12-sources.jar: cn/com/duiba/tuia/youtui/center/api/util/DataTool.java <==
package cn.com.duiba.tuia.youtui.center.api.util;

import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;
import java.util.Map;
import java.util.Objects;
import java.util.function.Function;

/**
 * author: 胡 朋
 * github: https://github.com/xiaomoinfo
 * email : xiaomo@xiaomo.info
 * QQ    : 83387856
 * Date  : 2018/7/10 11:21
 * desc  :
 */
public class DataTool {
    private DataTool(){}

    /**
     * 除法
     * @param num1
     * @param num2
     * @return
     */
    public static Long devide(Long num1, Long num2) {
        BigDecimal bigDivisor = new BigDecimal(num1);
        BigDecimal bigDividend = new BigDecimal(num2);
        return bigDivisor.divide(bigDividend, 0, BigDecimal.ROUND_HALF_UP).longValue();
    }


    /**
     * 向map里设置值

     */
    public static void mapPut(Map<String,String> map, String value, String name) {
        if(StringUtils.isNotBlank(value)&& !Objects.equals("null",value)){
            map.put(name,value);
        }
    }


    /** 类型转换 */
    public static <R> R convert(String value, Function<String, R> funtion) {
        if (StringUtils.isBlank(value)||Objects.equals("null",value)) {
            return null;
        }
        return funtion.apply(value);
    }

    /** 在extInfo中获取值 */
    public static String getValueFromExtInfo(String extInfo,String key,String defaultValue){

        if(StringUtils.isBlank(extInfo)){
            return defaultValue;
        }
        JSONObject jsonObject = JSONObject.parseObject(extInfo);
        return (String)jsonObject.getOrDefault(key,defaultValue);
    }

}

==> youtui-center-api-0.0.1.14-yuanwei15-20180801.113121-2-sources.jar: cn/com/duiba/tuia/youtui/center/api/util/DataTool.java <==
package cn.com.duiba.tuia.youtui.center.api.util;

import cn.com.duiba.tuia.youtui.center.api.dto.consumer.UserAccountCenter;
import cn.com.duiba.tuia.youtui.center.api.dto.youtui.MissionDto;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang3.StringUtils;

import java.math.BigDecimal;
import java.util.Map;
import java.util.Objects;
import java.util.function.Function;

/**
 * author: 胡 朋
 * github: https://github.com/xiaomoinfo
 * email : xiaomo@xiaomo.info
 * QQ    : 83387856
 * Date  : 2018/7/10 11:21
 * desc  :
 */
public class DataTool {
    private DataTool(){}

    /**
     * 除法
     * @param num1
     * @param num2
     * @return
     */
    public static Long devide(Long num1, Long num2) {
        BigDecimal bigDivisor = new BigDecimal(num1);
        BigDecimal bigDividend = new BigDecimal(num2);
        return bigDivisor.divide(bigDividend, 0, BigDecimal.ROUND_HALF_UP).longValue();
    }


    /**
     * 向map里设置值

     */
    public static void mapPut(Map<String,String> map, String value, String name) {
        if(StringUtils.isNotBlank(value)&& !Objects.equals("null",value)){
            map.put(name,value);
        }
    }


    /** 类型转换 */
    public static <R> R convert(String value, Function<String, R> funtion) {
        if (StringUtils.isBlank(value)||Objects.equals("null",value)) {
            return null;
        }
        return funtion.apply(value);
    }

    /** 在extInfo中获取值 */
    public static String getValueFromExtInfo(String extInfo,String key,String defaultValue){

        if(StringUtils.isBlank(extInfo)){
            return defaultValue;
        }
        JSONObject jsonObject = JSONObject.parseObject(extInfo);
        return (String)jsonObject.getOrDefault(key,defaultValue);
    }

    /**
     * 对任务进行排序
     * @param item1
     * @param item2
     * @return
     */
    public static int missionComparator(MissionDto item1,MissionDto item2){
        if(item1.getMissionGroup()<item2.getMissionGroup()){
            return -1;
        }
        if(item1.getMissionGroup()>item2.getMissionGroup()){
            return 1;
        }

        if(item1.getId()>item2.getId()){
            return 1;
        }
        if(item1.getId()<item2.getId()){
            return -1;
        }
        return 0;
    }

    /**
     * 判断是否是v1.2.0之后的user
     * @return
     */
    public static boolean isNewUser(UserAccountCenter userAccountCenter) {
        if(userAccountCenter ==null){
            return false;
        }
        return userAccountCenter.getMark()!=null&& userAccountCenter.getMark()>=1;
    }
}
